@@ -15,16 +15,20 @@ impl PollerWaker {
     }
 
     /// Mark the current set as woken.
-    fn wake(&self) {
+    fn wake_by_ref(&self) {
         self.waker.set.set(self.index);
-        self.waker.parent.wake();
+        self.waker.parent.wake_by_ref();
     }
 }
 
+// Note: Since all resources associated with the waker are statically allocated,
+// there's no need to free anything on calls to `wake` which otherwise takes
+// ownership of the waker. There is also nothing to drop and no work that needs
+// to happen when cloning.
 static VTABLE: &RawWakerVTable = &RawWakerVTable::new(
     |this| RawWaker::new(this, VTABLE),
-    |this| unsafe { (*(this as *const PollerWaker)).wake() },
-    |this| unsafe { (*(this as *const PollerWaker)).wake() },
+    |this| unsafe { (*(this as *const PollerWaker)).wake_by_ref() },
+    |this| unsafe { (*(this as *const PollerWaker)).wake_by_ref() },
     |_| {},
 );
 
